@@ -2,7 +2,6 @@
 from unittest import TestCase
 
 from lexicon.tests.providers.integration_tests import IntegrationTests
-from lexicon.providers.gandi import Provider
 
 
 # Hook into testing framework by inheriting unittest.TestCase and reuse
@@ -10,7 +9,6 @@ from lexicon.providers.gandi import Provider
 # pass, by inheritance from define_tests.TheTests
 class GandiRPCProviderTests(TestCase, IntegrationTests):
     """TestCase for Gandi on RPC"""
-    Provider = Provider
     provider_name = 'gandi'
     domain = 'reachlike.ca'
     provider_variant = 'RPC'
@@ -21,7 +19,6 @@ class GandiRPCProviderTests(TestCase, IntegrationTests):
 
 class GandiRESTProviderTests(TestCase, IntegrationTests):
     """TestCase for Gandi on REST API"""
-    Provider = Provider
     provider_name = 'gandi'
     domain = 't18s.fr'
     provider_variant = 'REST'
